#!/usr/bin/env bash

ABSDIR="$( dirname "$(readlink -f -- "$0")" )"
source ${ABSDIR}/../functions.sh
source ${ABSDIR}/vars.sh

ensure_pwd_is_scriptdir
ensure_not_root

ensure_variables_are_defined "$envvars"

if [[ ! -d ~/.local/share/containers/storage/volumes/${confvolume} ]]; then
    echo "Error : conf volume ${confvolume} does not exists. Consider running 05_freshinstall.sh if this is the first install."
    exit 1
fi

if [[ ! -d ~/.local/share/containers/storage/volumes/${dbvolume} ]]; then
    echo "Error : conf volume ${dbvolume} does not exists. Consider running 05_freshinstall.sh if this is the first install."
    exit 1
fi

# FAIL if pod exists
ensure_pod_not_exists ${pod_name}

podman pod create --publish ${listen_if}:8086:8008 --name ${pod_name} && \
podman run -d --name ${db_container_name} --pod ${pod_name} \
  --mount type=volume,src=${dbvolume},dst=/var/lib/postgresql/data/ \
  -e POSTGRES_PASSWORD=${GARBAYE_MATRIX_POSTGRES_PASSWORD} \
  -e POSTGRES_USER=${container_name} \
  -e POSTGRES_DB=${container_name} \
  -e POSTGRES_INITDB_ARGS="--encoding=UTF8 --locale=C" \
  ${postgres_image}:${postgres_version} && \
podman run -d --name ${container_name} --pod ${pod_name} \
  --mount type=volume,src=${confvolume},dst=/data ${synapse_image}:${synapse_version} && \
echo "Pod built and starting
run 'podman logs -f synapse synapse-db' to show initialisation status
then stop pod with 'podman pod stop ${pod_name}'"
